# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['docketalarm_api']

package_data = \
{'': ['*']}

install_requires = \
['requests>=2.26.0,<3.0.0']

setup_kwargs = {
    'name': 'docketalarm-api',
    'version': '1.0.1',
    'description': 'Wrapper to interact with DocketAlarm API',
    'long_description': '# DocketAlarmAPI\nAPI Wrapper for DocketAlarm.\n# Table of Contents\n1. [Instalation and usage](#usage)\n2. [Get Login Token](#get_login_token)\n3. [Search](#search)\n4. [Get Docket](#get_docket)\n5. [Get Document](#get_document_binary)\n6. [Ask Docket](#ask_docket)\n7. [Case Matcher](#case_matcher)\n8. [Smart Search](#smart_search)\n9. [Attorney Billing Rates](#attorney_billing_rates)\n10. [Get Complaint Summary](#get_complaint_summary)\n11. [Get Cause of Action](#get_cause_of_action)\n\n# usage\nUse `pip install docketalarm_api` to install this library.  \nTo use the DocketAlarmClient you\'ll need your DocketAlarm user and password, and if desired to interact with OpenAI powered endpoints, an OpenAI API Key.  \nImport and initialize the client as follows:\n```\nfrom docketalarm_api import DocketAlarmClient\n\nda_client = DocketAlarmClient(<your-docketalarm-user>, <your-docketalarm-password>, <your-openai-api-key>)\n```\n\n# General Endpoints\nThese are methods available directly to your DocketAlarm user through a `DocketAlarmClient` instance.\n\n## get_login_token\nGet authentication token from docketalarm.  \n\n**Example**:\n\n```\n    from docketalarm_api import DocketAlarmClient\n\n    da_client = DocketAlarmClient(<your-docketalarm-user>, <your-docketalarm-password>, <your-openai-api-key>)\n    login_token = da_client.get_login_token()\n```\n\n## search\nPerform a search on DocketAlarm API\'s search endpoint.  \n\n| Parameter    | Description                                         |\n|--------------|-----------------------------------------------------|\n| query        | The DocketAlarm query to use.                      |\n| order        | The order to get the results by.                   |\n| limit        | The search limit, must be 50 or less.              |\n| offset       | Offset for the search, useful for pagination.       |\n| login_token  | Will be created if not provided.                   |\n| return       | Dictionary with JSON response.                      |\n\n**Example**:\n\n```\n    response = da_client.search("is:docket AND is:state", "random", limit=10)\n    search_results = response["search_results"]\n```\n\n## get_docket\nInteract with getdocket endpoint, fetching a docket by court and docket number.  \n\n| Parameter       | Description                                       |\n|-----------------|---------------------------------------------------|\n| docket          | The docket number obtained from search.           |\n| court           | The court of the docket obtained from search.     |\n| timeout         | Timeout for the GET request.                      |\n| client_matter   | The client matter for the API call.               |\n| normalize       | Normalize option for getdocket endpoint.          |\n| cached          | Defaults to True, gets cached version of the docket. |\n| login_token     | If not provided it\'s auto-generated.             |\n| return          | Dictionary with JSON response.                    |\n\n**Example**:\n\n```\n    docket_data = da_client.get_docket(docket="JC205-106", court="Texas State, Grayson County, Justice of the Peace 2")\n```\n\n## get_document_binary\nFetches the binary content of a pdf stored in DocketAlarm or directly from the court.  \n\n| Parameter    | Description                                           |\n|--------------|-------------------------------------------------------|\n| doc_url      | URL for the document.                                 |\n| login_token  | Token for OpenAI authentication.                      |\n| client_matter| The matter or client for the API call.                |\n| cached       | Boolean stating if desired to use cached version of the document or not. |\n| return       | Document binary (bytes).                              |\n\n**Example**:\n\n```\n    document_bytes = da_client.get_document_binary(\n        \'https://www.docketalarm.com/cases/Arkansas_State_Faulkner_County_Circuit_Court/23DR-98-821/OCSE_V_JOHN_TAYLOR/docs/28082014_OTHER_0.pdf\'\n    )\n```\n\n# OpenAI Endpoints\n\nThese methods require the use of an OpenAI API key, suplied when initializing the instance.  \nYou can check if an OpenAI API key is valid using the `DocketAlarmClient.is_openai_valid_api_key` method.\n\n## ask_docket\nInteract with DocketAlarm\'s ask_docket OpenAI endpoint.  \n\n| Parameter       | Description                                                      |\n|-----------------|------------------------------------------------------------------|\n| docket          | The docket number as extracted from search.                      |\n| court           | The court of the docket as extracted from search.                |\n| question        | The question to ask to the docket data.                          |\n| output_format   | The output format of the desired response in natural language.   |\n| target          | The target for ask_docket, "dockets", "documents" or "both".     |\n| openai_model    | Model to be used on OpenAI interactions, defaults to gpt-3.5-turbo-1106. |\n| cached          | Gets cached version of the docket on the interaction, defaults to False. |\n| show_relevant   | Gets relevant data used by ask_docket.                           |\n| login_token     | If not provided, it is autogenerated.                           |\n| return          | Dictionary with JSON response.                                   |\n\n**Example**:\n\n```\n    response = da_client.ask_docket(docket=\'JC205-106\', court=\'Texas State, Grayson County, Justice of the Peace 2\',\n                                    question=\'is the case pre or post discovery stages?\',\n                                    output_format=\'Enum["pre" or "post" or "unknown"]\',\n                                    target="dockets", cached = True)\n\n    openai_answer = response["from_dockets"]["openai_answer"]\n```\n\n## case_matcher\nMatch a case from any input provided using DocketAlarm\'s OpenAI powered case_matcher endpoint.  \n\n| Parameter       | Description                                                      |\n|-----------------|------------------------------------------------------------------|\n| openai_model    | The OpenAI model to use during case matching.                    |\n| kwargs          | Provide any argument and it will be used as inputs in case matcher. |\n| return          | Dictionary with result from case matcher and OpenAI costs incurred. |\n\n**Example**:\n\n```\n    response = da_client.case_matcher(openai_model="gpt-4-1106-preview",\n                                    description="A PACER case involving Cloud Systems HoldCo in California")\n    case_link = response["result"]["Link"]\n```\n\n## smart_search\nReturn a query for DocketAlarm search based on instructions in natural language  \n\n| Parameter       | Description                                                     |\n|-----------------|-----------------------------------------------------------------|\n| instructions    | Instructions to build a query by.                               |\n| openai_model    | OpenAI model to be used when generating the query.              |\n| login_token     | If not provided, it will be auto-generated.                     |\n| return          | Dictionary with query and OpenAI costs incurred.                |\n\n**Example**:\n\n```\n    response = da_client.smart_search(\n        instructions="Cases involving Ford Motor in New York, that span from December 2014 to june 2019"\n    )\n    query = response["query"]\n```\n\n## attorney_billing_rates\nExtract attorney billing rates by name and state.  \n\n| Parameter       | Description                                                     |\n|-----------------|-----------------------------------------------------------------|\n| attorney_name   | The name of the attorney for which billing rates are to be extracted. |\n| state           | The state of the attorney.                                      |\n| openai_model    | OpenAI model to be used on the API call.                         |\n| login_token     | Auto-generated by default.                                      |\n| client_matter   | Empty by default.                                                |\n| return          | Dictionary with result and OpenAI costs incurred.               |\n\n**Example**\n\n```\n    response = da_client.attorney_billing_rates(attorney_name="ashley marshal",\n                                                state="connecticut")\n    attorney_data = response["result"]\n```\n\n## get_complaint_summary\nGet a summary of the legal complaint in the docket.  \n\n| Parameter       | Description                                                     |\n|-----------------|-----------------------------------------------------------------|\n| docket          | Docket number.                                                  |\n| court           | The court of the docket.                                        |\n| openai_model    | The OpenAI model to be used on the API call.                    |\n| login_token     | Auto-generated by default.                                      |\n| cached          | Bool stating if desired to use cached version of the docket.    |\n| short           | Extract a short complaint summary.                              |\n| return          | Dictionary with complaint summary and OpenAI costs incurred.    |\n\n**Example**:\n\n```\n    response = da_client.get_complaint_summary(docket="JC205-106", court="Texas State, Grayson County, Justice of the Peace 2",\n                                            short=True, openai_model="gpt-4-1106-preview", cached=True)\n    openai_answer = response["openai_answer"]\n```\n\n## get_cause_of_action\nGet the causes of action from a legal complaint.  \n\n| Parameter       | Description                                                     |\n|-----------------|-----------------------------------------------------------------|\n| docket          | Docket number.                                                  |\n| court           | The court of the docket.                                        |\n| openai_model    | The OpenAI model to be used on the API call.                    |\n| login_token     | Auto-generated by default.                                      |\n| cached          | Bool stating if desired to use cached version of the docket.    |\n| return          | Dictionary with cause of action and OpenAI costs incurred.      |\n\n**Example**:\n\n```\n    response = da_client.get_cause_of_action(docket="JC205-106", court="Texas State, Grayson County, Justice of the Peace 2",\n                                            openai_model="gpt-4-1106-preview", cached=True)\n    openai_answer = response["openai_answer"]\n```\n\n## entity_normalizer\nGet a DocketAlarm query for the entity normalized  \n\n| Parameter           | Description                                                            |\n|---------------------|------------------------------------------------------------------------|\n| entity              | The entity to normalize.                                               |\n| include_corp_group | Boolean stating if desired to include corporation group matches.       |\n| search_limit        | The internal search limit when optimizing. Must be between 10 and 50.  |\n| login_token         | If not provided, it is autogenerated.                                  |\n\n**Example**:\n\n```\n    response = da_client.entity_normalizer(entity="Apple", search_limit=20,\n                                           include_corp_group=True)\n    query = response["query"]\n```',
    'author': 'Ezequiel Ghiena',
    'author_email': 'ezequiel.ghiena@vlex.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://www.docketalarm.com/dockets/',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.8,<4.0',
}


setup(**setup_kwargs)
